@@ -210,7 +210,6 @@ pub(super) fn reflect<'a, I>(
     words: &[u32],
     types_meta: &TypesMeta,
     input_paths: I,
-    exact_entrypoint_interface: bool,
     shared_constants: bool,
     types_registry: &'a mut HashMap<String, RegisteredType>,
 ) -> Result<(TokenStream, TokenStream), Error>
@@ -232,7 +231,7 @@ where
         let minor = spirv.version().minor;
         let patch = spirv.version().patch;
         quote! {
-            Version {
+            ::vulkano::Version {
                 major: #major,
                 minor: #minor,
                 patch: #patch,
@@ -241,10 +240,10 @@ where
     };
     let spirv_capabilities = reflect::spirv_capabilities(&spirv).map(|capability| {
         let name = format_ident!("{}", format!("{:?}", capability));
-        quote! { &Capability::#name }
+        quote! { &::vulkano::shader::spirv::Capability::#name }
     });
     let spirv_extensions = reflect::spirv_extensions(&spirv);
-    let entry_points = reflect::entry_points(&spirv, exact_entrypoint_interface)
+    let entry_points = reflect::entry_points(&spirv)
         .map(|(name, model, info)| entry_point::write_entry_point(&name, model, &info));
 
     let specialization_constants = structs::write_specialization_constants(
@@ -268,21 +267,12 @@ where
         pub fn #load_name(device: ::std::sync::Arc<::vulkano::device::Device>)
             -> Result<::std::sync::Arc<::vulkano::shader::ShaderModule>, ::vulkano::shader::ShaderCreationError>
         {
-            use vulkano::shader::EntryPointInfo;
-            use vulkano::shader::GeometryShaderExecution;
-            use vulkano::shader::ShaderExecution;
-            use vulkano::shader::ShaderModule;
-            use vulkano::shader::ShaderStage;
-            use vulkano::shader::SpecializationConstantRequirements;
-            use vulkano::shader::spirv::Capability;
-            use vulkano::Version;
-
             let _bytes = ( #( #include_bytes),* );
 
             static WORDS: &[u32] = &[ #( #words ),* ];
 
             unsafe {
-                Ok(ShaderModule::from_words_with_data(
+                Ok(::vulkano::shader::ShaderModule::from_words_with_data(
                     device,
                     WORDS,
                     #spirv_version,
@@ -711,7 +701,7 @@ mod tests {
         let spirv = Spirv::new(&instructions).unwrap();
 
         let mut descriptors = Vec::new();
-        for (_, _, info) in reflect::entry_points(&spirv, true) {
+        for (_, _, info) in reflect::entry_points(&spirv) {
             descriptors.push(info.descriptor_requirements);
         }
 
@@ -782,7 +772,7 @@ mod tests {
         .unwrap();
         let spirv = Spirv::new(comp.as_binary()).unwrap();
 
-        for (_, _, info) in reflect::entry_points(&spirv, true) {
+        for (_, _, info) in reflect::entry_points(&spirv) {
             let mut bindings = Vec::new();
             for (loc, _reqs) in info.descriptor_requirements {
                 bindings.push(loc);
